Package: bsvarSIGNs
Type: Package
Title: Bayesian SVARs with Sign, Zero, and Narrative Restrictions
Version: 2.0
Date: 2025-01-28
Authors@R: c(person("Xiaolei", "Wang", , "adamwang15@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0009-0005-6192-9061")),person("Tomasz", "Woźniak", , "wozniak.tom@pm.me", role = c("aut"), comment = c(ORCID = "0000-0003-2212-2378")))
Maintainer: Xiaolei Wang <adamwang15@gmail.com>
Description: Implements state-of-the-art algorithms for the Bayesian analysis of Structural Vector Autoregressions (SVARs) identified by sign, zero, and narrative restrictions. The core model is based on a flexible Vector Autoregression with estimated hyper-parameters of the Minnesota prior and the dummy observation priors as in Giannone, Lenza, Primiceri (2015) <doi:10.1162/REST_a_00483>. The sign restrictions are implemented employing the methods proposed by Rubio-Ramírez, Waggoner & Zha (2010) <doi:10.1111/j.1467-937X.2009.00578.x>, while identification through sign and zero restrictions follows the approach developed by Arias, Rubio-Ramírez, & Waggoner (2018) <doi:10.3982/ECTA14468>. Furthermore, our tool provides algorithms for identification via sign and narrative restrictions, in line with the methods introduced by Antolín-Díaz and Rubio-Ramírez (2018) <doi:10.1257/aer.20161852>. Users can also estimate a model with sign, zero, and narrative restrictions imposed at once. The package facilitates predictive and structural analyses using impulse responses, forecast error variance and historical decompositions, forecasting and conditional forecasting, as well as analyses of structural shocks and fitted values. All this is complemented by colourful plots, user-friendly summary functions, and comprehensive documentation including the vignette by Wang & Woźniak (2024) <doi:10.48550/arXiv.2501.16711>. The 'bsvarSIGNs' package is aligned regarding objects, workflows, and code structure with the R package 'bsvars' by Woźniak (2024) <doi:10.32614/CRAN.package.bsvars>, and they constitute an integrated toolset. It was granted the Di Cook Open-Source Statistical Software Award by the Statistical Society of Australia in 2024.
License: GPL (>= 3)
Imports: Rcpp (>= 1.0.12), RcppProgress, R6
LinkingTo: Rcpp, RcppArmadillo, RcppProgress, bsvars
Depends: R (>= 4.1.0), RcppArmadillo, bsvars
Suggests: knitr, tinytest
URL: https://bsvars.org/bsvarSIGNs/
BugReports: https://github.com/bsvars/bsvarSIGNs/issues
Encoding: UTF-8
LazyData: true
VignetteBuilder: knitr
RoxygenNote: 7.3.2
NeedsCompilation: yes
Packaged: 2025-01-30 02:32:02 UTC; adam
Author: Xiaolei Wang [aut, cre] (<https://orcid.org/0009-0005-6192-9061>),
  Tomasz Woźniak [aut] (<https://orcid.org/0000-0003-2212-2378>)
Repository: CRAN
Date/Publication: 2025-01-30 03:20:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 02:58:36 UTC; unix
Archs: bsvarSIGNs.so.dSYM
