# Generated by roxygen2: do not edit by hand

S3method(compute_conditional_sd,PosteriorBSVARSIGN)
S3method(compute_fitted_values,PosteriorBSVARSIGN)
S3method(compute_historical_decompositions,PosteriorBSVARSIGN)
S3method(compute_impulse_responses,PosteriorBSVARSIGN)
S3method(compute_structural_shocks,PosteriorBSVARSIGN)
S3method(compute_variance_decompositions,PosteriorBSVARSIGN)
S3method(estimate,BSVARSIGN)
S3method(forecast,PosteriorBSVARSIGN)
export(specify_bsvarSIGN)
export(specify_identification_bsvarSIGN)
export(specify_narrative)
export(specify_posterior_bsvarSIGN)
export(specify_prior_bsvarSIGN)
import(RcppArmadillo)
import(RcppProgress)
import(bsvars)
importFrom(R6,R6Class)
importFrom(Rcpp,sourceCpp)
importFrom(bsvars,compute_fitted_values)
importFrom(bsvars,compute_historical_decompositions)
importFrom(bsvars,compute_impulse_responses)
importFrom(bsvars,compute_structural_shocks)
importFrom(bsvars,compute_variance_decompositions)
importFrom(bsvars,estimate)
importFrom(bsvars,forecast)
useDynLib(bsvarSIGNs, .registration = TRUE)
